# The Block Editor’s Data

Namespace: `core/block-editor`.

## Selectors

<!-- START TOKEN(Autogenerated selectors|../../../../packages/block-editor/src/store/selectors.js) -->

<a name="areInnerBlocksControlled" href="#areInnerBlocksControlled">#</a> **areInnerBlocksControlled**

Checks if a given block has controlled inner blocks.

_Parameters_

-   _state_ `Object`: Global application state.
-   _clientId_ `string`: The block to check.

_Returns_

-   `boolean`: True if the block has controlled inner blocks.

<a name="canInsertBlockType" href="#canInsertBlockType">#</a> **canInsertBlockType**

Determines if the given block type is allowed to be inserted into the block list.

_Parameters_

-   _state_ `Object`: Editor state.
-   _blockName_ `string`: The name of the block type, e.g.' core/paragraph'.
-   _rootClientId_ `?string`: Optional root client ID of block list.

_Returns_

-   `boolean`: Whether the given block type is allowed to be inserted.

<a name="didAutomaticChange" href="#didAutomaticChange">#</a> **didAutomaticChange**

Returns true if the last change was an automatic change, false otherwise.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether the last change was automatic.

<a name="getAdjacentBlockClientId" href="#getAdjacentBlockClientId">#</a> **getAdjacentBlockClientId**

Returns the client ID of the block adjacent one at the given reference
startClientId and modifier directionality. Defaults start startClientId to
the selected block, and direction as next block. Returns null if there is no
adjacent block.

_Parameters_

-   _state_ `Object`: Editor state.
-   _startClientId_ `?string`: Optional client ID of block from which to search.
-   _modifier_ `?number`: Directionality multiplier (1 next, -1 previous).

_Returns_

-   `?string`: Return the client ID of the block, or null if none exists.

<a name="getBlock" href="#getBlock">#</a> **getBlock**

Returns a block given its client ID. This is a parsed copy of the block,
containing its `blockName`, `clientId`, and current `attributes` state. This
is not the block's registration settings, which must be retrieved from the
blocks module registration store.

getBlock recurses through its inner blocks until all its children blocks have
been retrieved. Note that getBlock will not return the child inner blocks of
an inner block controller. This is because an inner block controller syncs
itself with its own entity, and should therefore not be included with the
blocks of a different entity. For example, say you call `getBlocks( TP )` to
get the blocks of a template part. If another template part is a child of TP,
then the nested template part's child blocks will not be returned. This way,
the template block itself is considered part of the parent, but the children
are not.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: Block client ID.

_Returns_

-   `Object`: Parsed block object.

<a name="getBlockAttributes" href="#getBlockAttributes">#</a> **getBlockAttributes**

Returns a block's attributes given its client ID, or null if no block exists with
the client ID.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: Block client ID.

_Returns_

-   `?Object`: Block attributes.

<a name="getBlockCount" href="#getBlockCount">#</a> **getBlockCount**

Returns the number of blocks currently present in the post.

_Parameters_

-   _state_ `Object`: Editor state.
-   _rootClientId_ `?string`: Optional root client ID of block list.

_Returns_

-   `number`: Number of blocks in the post.

<a name="getBlockHierarchyRootClientId" href="#getBlockHierarchyRootClientId">#</a> **getBlockHierarchyRootClientId**

Given a block client ID, returns the root of the hierarchy from which the block is nested, return the block itself for root level blocks.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: Block from which to find root client ID.

_Returns_

-   `string`: Root client ID

<a name="getBlockIndex" href="#getBlockIndex">#</a> **getBlockIndex**

Returns the index at which the block corresponding to the specified client
ID occurs within the block order, or `-1` if the block does not exist.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: Block client ID.
-   _rootClientId_ `?string`: Optional root client ID of block list.

_Returns_

-   `number`: Index at which block exists in order.

<a name="getBlockInsertionPoint" href="#getBlockInsertionPoint">#</a> **getBlockInsertionPoint**

Returns the insertion point, the index at which the new inserted block would
be placed. Defaults to the last index.

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `Object`: Insertion point object with `rootClientId`, `index`.

<a name="getBlockListSettings" href="#getBlockListSettings">#</a> **getBlockListSettings**

Returns the Block List settings of a block, if any exist.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `?string`: Block client ID.

_Returns_

-   `?Object`: Block settings of the block if set.

<a name="getBlockMode" href="#getBlockMode">#</a> **getBlockMode**

Returns the block's editing mode, defaulting to "visual" if not explicitly
assigned.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: Block client ID.

_Returns_

-   `Object`: Block editing mode.

<a name="getBlockName" href="#getBlockName">#</a> **getBlockName**

Returns a block's name given its client ID, or null if no block exists with
the client ID.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: Block client ID.

_Returns_

-   `string`: Block name.

<a name="getBlockOrder" href="#getBlockOrder">#</a> **getBlockOrder**

Returns an array containing all block client IDs in the editor in the order
they appear. Optionally accepts a root client ID of the block list for which
the order should be returned, defaulting to the top-level block order.

_Parameters_

-   _state_ `Object`: Editor state.
-   _rootClientId_ `?string`: Optional root client ID of block list.

_Returns_

-   `Array`: Ordered client IDs of editor blocks.

<a name="getBlockParents" href="#getBlockParents">#</a> **getBlockParents**

Given a block client ID, returns the list of all its parents from top to bottom.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: Block from which to find root client ID.
-   _ascending_ `boolean`: Order results from bottom to top (true) or top to bottom (false).

_Returns_

-   `Array`: ClientIDs of the parent blocks.

<a name="getBlockParentsByBlockName" href="#getBlockParentsByBlockName">#</a> **getBlockParentsByBlockName**

Given a block client ID and a block name,
returns the list of all its parents from top to bottom,
filtered by the given name.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: Block from which to find root client ID.
-   _blockName_ `string`: Block name to filter.
-   _ascending_ `boolean`: Order results from bottom to top (true) or top to bottom (false).

_Returns_

-   `Array`: ClientIDs of the parent blocks.

<a name="getBlockRootClientId" href="#getBlockRootClientId">#</a> **getBlockRootClientId**

Given a block client ID, returns the root block from which the block is
nested, an empty string for top-level blocks, or null if the block does not
exist.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: Block from which to find root client ID.

_Returns_

-   `?string`: Root client ID, if exists

<a name="getBlocks" href="#getBlocks">#</a> **getBlocks**

Returns all block objects for the current post being edited as an array in
the order they appear in the post. Note that this will exclude child blocks
of nested inner block controllers.

Note: It's important to memoize this selector to avoid return a new instance
on each call. We use the block cache state for each top-level block of the
given clientID. This way, the selector only refreshes on changes to blocks
associated with the given entity, and does not refresh when changes are made
to blocks which are part of different inner block controllers.

_Parameters_

-   _state_ `Object`: Editor state.
-   _rootClientId_ `?string`: Optional root client ID of block list.

_Returns_

-   `Array<Object>`: Post blocks.

<a name="getBlocksByClientId" href="#getBlocksByClientId">#</a> **getBlocksByClientId**

Given an array of block client IDs, returns the corresponding array of block
objects.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientIds_ `Array<string>`: Client IDs for which blocks are to be returned.

_Returns_

-   `Array<WPBlock>`: Block objects.

<a name="getBlockSelectionEnd" href="#getBlockSelectionEnd">#</a> **getBlockSelectionEnd**

Returns the current block selection end. This value may be null, and it
may represent either a singular block selection or multi-selection end.
A selection is singular if its start and end match.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `?string`: Client ID of block selection end.

<a name="getBlockSelectionStart" href="#getBlockSelectionStart">#</a> **getBlockSelectionStart**

Returns the current block selection start. This value may be null, and it
may represent either a singular block selection or multi-selection start.
A selection is singular if its start and end match.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `?string`: Client ID of block selection start.

<a name="getClientIdsOfDescendants" href="#getClientIdsOfDescendants">#</a> **getClientIdsOfDescendants**

Returns an array containing the clientIds of all descendants
of the blocks given.

_Parameters_

-   _state_ `Object`: Global application state.
-   _clientIds_ `Array`: Array of blocks to inspect.

_Returns_

-   `Array`: ids of descendants.

<a name="getClientIdsWithDescendants" href="#getClientIdsWithDescendants">#</a> **getClientIdsWithDescendants**

Returns an array containing the clientIds of the top-level blocks
and their descendants of any depth (for nested blocks).

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `Array`: ids of top-level and descendant blocks.

<a name="getFirstMultiSelectedBlockClientId" href="#getFirstMultiSelectedBlockClientId">#</a> **getFirstMultiSelectedBlockClientId**

Returns the client ID of the first block in the multi-selection set, or null
if there is no multi-selection.

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `?string`: First block client ID in the multi-selection set.

<a name="getGlobalBlockCount" href="#getGlobalBlockCount">#</a> **getGlobalBlockCount**

Returns the total number of blocks, or the total number of blocks with a specific name in a post.
The number returned includes nested blocks.

_Parameters_

-   _state_ `Object`: Global application state.
-   _blockName_ `?string`: Optional block name, if specified only blocks of that type will be counted.

_Returns_

-   `number`: Number of blocks in the post, or number of blocks with name equal to blockName.

<a name="getInserterItems" href="#getInserterItems">#</a> **getInserterItems**

Determines the items that appear in the inserter. Includes both static
items (e.g. a regular block type) and dynamic items (e.g. a reusable block).

Each item object contains what's necessary to display a button in the
inserter and handle its selection.

The 'frecency' property is a heuristic (<https://en.wikipedia.org/wiki/Frecency>)
that combines block usage frequenty and recency.

Items are returned ordered descendingly by their 'utility' and 'frecency'.

_Parameters_

-   _state_ `Object`: Editor state.
-   _rootClientId_ `?string`: Optional root client ID of block list.

_Returns_

-   `Array<WPEditorInserterItem>`: Items that appear in inserter.

_Type Definition_

-   _WPEditorInserterItem_ `Object`

_Properties_

-   _id_ `string`: Unique identifier for the item.
-   _name_ `string`: The type of block to create.
-   _initialAttributes_ `Object`: Attributes to pass to the newly created block.
-   _title_ `string`: Title of the item, as it appears in the inserter.
-   _icon_ `string`: Dashicon for the item, as it appears in the inserter.
-   _category_ `string`: Block category that the item is associated with.
-   _keywords_ `Array<string>`: Keywords that can be searched to find this item.
-   _isDisabled_ `boolean`: Whether or not the user should be prevented from inserting this item.
-   _frecency_ `number`: Hueristic that combines frequency and recency.

<a name="getLastMultiSelectedBlockClientId" href="#getLastMultiSelectedBlockClientId">#</a> **getLastMultiSelectedBlockClientId**

Returns the client ID of the last block in the multi-selection set, or null
if there is no multi-selection.

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `?string`: Last block client ID in the multi-selection set.

<a name="getLowestCommonAncestorWithSelectedBlock" href="#getLowestCommonAncestorWithSelectedBlock">#</a> **getLowestCommonAncestorWithSelectedBlock**

Given a block client ID, returns the lowest common ancestor with selected client ID.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: Block from which to find common ancestor client ID.

_Returns_

-   `string`: Common ancestor client ID or undefined

<a name="getMultiSelectedBlockClientIds" href="#getMultiSelectedBlockClientIds">#</a> **getMultiSelectedBlockClientIds**

Returns the current multi-selection set of block client IDs, or an empty
array if there is no multi-selection.

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `Array`: Multi-selected block client IDs.

<a name="getMultiSelectedBlocks" href="#getMultiSelectedBlocks">#</a> **getMultiSelectedBlocks**

Returns the current multi-selection set of blocks, or an empty array if
there is no multi-selection.

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `Array`: Multi-selected block objects.

<a name="getMultiSelectedBlocksEndClientId" href="#getMultiSelectedBlocksEndClientId">#</a> **getMultiSelectedBlocksEndClientId**

Returns the client ID of the block which ends the multi-selection set, or
null if there is no multi-selection.

This is not necessarily the last client ID in the selection.

_Related_

-   getLastMultiSelectedBlockClientId

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `?string`: Client ID of block ending multi-selection.

<a name="getMultiSelectedBlocksStartClientId" href="#getMultiSelectedBlocksStartClientId">#</a> **getMultiSelectedBlocksStartClientId**

Returns the client ID of the block which begins the multi-selection set, or
null if there is no multi-selection.

This is not necessarily the first client ID in the selection.

_Related_

-   getFirstMultiSelectedBlockClientId

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `?string`: Client ID of block beginning multi-selection.

<a name="getNextBlockClientId" href="#getNextBlockClientId">#</a> **getNextBlockClientId**

Returns the next block's client ID from the given reference start ID.
Defaults start to the selected block. Returns null if there is no next
block.

_Parameters_

-   _state_ `Object`: Editor state.
-   _startClientId_ `?string`: Optional client ID of block from which to search.

_Returns_

-   `?string`: Adjacent block's client ID, or null if none exists.

<a name="getPreviousBlockClientId" href="#getPreviousBlockClientId">#</a> **getPreviousBlockClientId**

Returns the previous block's client ID from the given reference start ID.
Defaults start to the selected block. Returns null if there is no previous
block.

_Parameters_

-   _state_ `Object`: Editor state.
-   _startClientId_ `?string`: Optional client ID of block from which to search.

_Returns_

-   `?string`: Adjacent block's client ID, or null if none exists.

<a name="getSelectedBlock" href="#getSelectedBlock">#</a> **getSelectedBlock**

Returns the currently selected block, or null if there is no selected block.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `?Object`: Selected block.

<a name="getSelectedBlockClientId" href="#getSelectedBlockClientId">#</a> **getSelectedBlockClientId**

Returns the currently selected block client ID, or null if there is no
selected block.

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `?string`: Selected block client ID.

<a name="getSelectedBlockClientIds" href="#getSelectedBlockClientIds">#</a> **getSelectedBlockClientIds**

Returns the current selection set of block client IDs (multiselection or single selection).

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `Array`: Multi-selected block client IDs.

<a name="getSelectedBlockCount" href="#getSelectedBlockCount">#</a> **getSelectedBlockCount**

Returns the number of blocks currently selected in the post.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `number`: Number of blocks selected in the post.

<a name="getSelectedBlocksInitialCaretPosition" href="#getSelectedBlocksInitialCaretPosition">#</a> **getSelectedBlocksInitialCaretPosition**

Returns the initial caret position for the selected block.
This position is to used to position the caret properly when the selected block changes.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `?Object`: Selected block.

<a name="getSelectionEnd" href="#getSelectionEnd">#</a> **getSelectionEnd**

Returns the current selection end block client ID, attribute key and text
offset.

_Parameters_

-   _state_ `Object`: Block editor state.

_Returns_

-   `WPBlockSelection`: Selection end information.

<a name="getSelectionStart" href="#getSelectionStart">#</a> **getSelectionStart**

Returns the current selection start block client ID, attribute key and text
offset.

_Parameters_

-   _state_ `Object`: Block editor state.

_Returns_

-   `WPBlockSelection`: Selection start information.

<a name="getSettings" href="#getSettings">#</a> **getSettings**

Returns the editor settings.

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `Object`: The editor settings object.

<a name="getTemplate" href="#getTemplate">#</a> **getTemplate**

Returns the defined block template

_Parameters_

-   _state_ `boolean`: 

_Returns_

-   `?Array`: Block Template

<a name="getTemplateLock" href="#getTemplateLock">#</a> **getTemplateLock**

Returns the defined block template lock. Optionally accepts a root block
client ID as context, otherwise defaulting to the global context.

_Parameters_

-   _state_ `Object`: Editor state.
-   _rootClientId_ `?string`: Optional block root client ID.

_Returns_

-   `?string`: Block Template Lock

<a name="hasInserterItems" href="#hasInserterItems">#</a> **hasInserterItems**

Determines whether there are items to show in the inserter.

_Parameters_

-   _state_ `Object`: Editor state.
-   _rootClientId_ `?string`: Optional root client ID of block list.

_Returns_

-   `boolean`: Items that appear in inserter.

<a name="hasMultiSelection" href="#hasMultiSelection">#</a> **hasMultiSelection**

Returns true if a multi-selection has been made, or false otherwise.

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `boolean`: Whether multi-selection has been made.

<a name="hasSelectedBlock" href="#hasSelectedBlock">#</a> **hasSelectedBlock**

Returns true if there is a single selected block, or false otherwise.

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `boolean`: Whether a single block is selected.

<a name="hasSelectedInnerBlock" href="#hasSelectedInnerBlock">#</a> **hasSelectedInnerBlock**

Returns true if one of the block's inner blocks is selected.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: Block client ID.
-   _deep_ `boolean`: Perform a deep check.

_Returns_

-   `boolean`: Whether the block as an inner block selected

<a name="isAncestorMultiSelected" href="#isAncestorMultiSelected">#</a> **isAncestorMultiSelected**

Returns true if an ancestor of the block is multi-selected, or false
otherwise.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: Block client ID.

_Returns_

-   `boolean`: Whether an ancestor of the block is in multi-selection set.

<a name="isBlockHighlighted" href="#isBlockHighlighted">#</a> **isBlockHighlighted**

Returns true if the current highlighted block matches the block clientId.

_Parameters_

-   _state_ `Object`: Global application state.
-   _clientId_ `string`: The block to check.

_Returns_

-   `boolean`: Whether the block is currently highlighted.

<a name="isBlockInsertionPointVisible" href="#isBlockInsertionPointVisible">#</a> **isBlockInsertionPointVisible**

Returns true if we should show the block insertion point.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `?boolean`: Whether the insertion point is visible or not.

<a name="isBlockMultiSelected" href="#isBlockMultiSelected">#</a> **isBlockMultiSelected**

Returns true if the client ID occurs within the block multi-selection, or
false otherwise.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: Block client ID.

_Returns_

-   `boolean`: Whether block is in multi-selection set.

<a name="isBlockSelected" href="#isBlockSelected">#</a> **isBlockSelected**

Returns true if the block corresponding to the specified client ID is
currently selected and no multi-selection exists, or false otherwise.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: Block client ID.

_Returns_

-   `boolean`: Whether block is selected and multi-selection exists.

<a name="isBlockValid" href="#isBlockValid">#</a> **isBlockValid**

Returns whether a block is valid or not.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: Block client ID.

_Returns_

-   `boolean`: Is Valid.

<a name="isBlockWithinSelection" href="#isBlockWithinSelection">#</a> **isBlockWithinSelection**

Returns true if the block corresponding to the specified client ID is
currently selected but isn't the last of the selected blocks. Here "last"
refers to the block sequence in the document, _not_ the sequence of
multi-selection, which is why `state.selectionEnd` isn't used.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: Block client ID.

_Returns_

-   `boolean`: Whether block is selected and not the last in the selection.

<a name="isCaretWithinFormattedText" href="#isCaretWithinFormattedText">#</a> **isCaretWithinFormattedText**

Returns true if the caret is within formatted text, or false otherwise.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether the caret is within formatted text.

<a name="isDraggingBlocks" href="#isDraggingBlocks">#</a> **isDraggingBlocks**

Returns true if the user is dragging blocks, or false otherwise.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether user is dragging blocks.

<a name="isFirstMultiSelectedBlock" href="#isFirstMultiSelectedBlock">#</a> **isFirstMultiSelectedBlock**

Returns true if a multi-selection exists, and the block corresponding to the
specified client ID is the first block of the multi-selection set, or false
otherwise.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: Block client ID.

_Returns_

-   `boolean`: Whether block is first in multi-selection.

<a name="isLastBlockChangePersistent" href="#isLastBlockChangePersistent">#</a> **isLastBlockChangePersistent**

Returns true if the most recent block change is be considered persistent, or
false otherwise. A persistent change is one committed by BlockEditorProvider
via its `onChange` callback, in addition to `onInput`.

_Parameters_

-   _state_ `Object`: Block editor state.

_Returns_

-   `boolean`: Whether the most recent block change was persistent.

<a name="isMultiSelecting" href="#isMultiSelecting">#</a> **isMultiSelecting**

Whether in the process of multi-selecting or not. This flag is only true
while the multi-selection is being selected (by mouse move), and is false
once the multi-selection has been settled.

_Related_

-   hasMultiSelection

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: True if multi-selecting, false if not.

<a name="isNavigationMode" href="#isNavigationMode">#</a> **isNavigationMode**

Returns whether the navigation mode is enabled.

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `boolean`: Is navigation mode enabled.

<a name="isSelectionEnabled" href="#isSelectionEnabled">#</a> **isSelectionEnabled**

Selector that returns if multi-selection is enabled or not.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: True if it should be possible to multi-select blocks, false if multi-selection is disabled.

<a name="isTyping" href="#isTyping">#</a> **isTyping**

Returns true if the user is typing, or false otherwise.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether user is typing.

<a name="isValidTemplate" href="#isValidTemplate">#</a> **isValidTemplate**

Returns whether the blocks matches the template or not.

_Parameters_

-   _state_ `boolean`: 

_Returns_

-   `?boolean`: Whether the template is valid or not.

<!-- END TOKEN(Autogenerated selectors|../../../../packages/block-editor/src/store/selectors.js) -->

## Actions

<!-- START TOKEN(Autogenerated actions|../../../../packages/block-editor/src/store/actions.js) -->

<a name="clearSelectedBlock" href="#clearSelectedBlock">#</a> **clearSelectedBlock**

Returns an action object used in signalling that the block selection is cleared.

_Returns_

-   `Object`: Action object.

<a name="duplicateBlocks" href="#duplicateBlocks">#</a> **duplicateBlocks**

Generator that triggers an action used to duplicate a list of blocks.

_Parameters_

-   _clientIds_ `Array<string>`: 

<a name="enterFormattedText" href="#enterFormattedText">#</a> **enterFormattedText**

Returns an action object used in signalling that the caret has entered formatted text.

_Returns_

-   `Object`: Action object.

<a name="exitFormattedText" href="#exitFormattedText">#</a> **exitFormattedText**

Returns an action object used in signalling that the user caret has exited formatted text.

_Returns_

-   `Object`: Action object.

<a name="flashBlock" href="#flashBlock">#</a> **flashBlock**

Yields action objects used in signalling that the block corresponding to the
given clientId should appear to "flash" by rhythmically highlighting it.

_Parameters_

-   _clientId_ `string`: Target block client ID.

<a name="hideInsertionPoint" href="#hideInsertionPoint">#</a> **hideInsertionPoint**

Returns an action object hiding the insertion point.

_Returns_

-   `Object`: Action object.

<a name="insertAfterBlock" href="#insertAfterBlock">#</a> **insertAfterBlock**

Generator used to insert an empty block before a given block.

_Parameters_

-   _clientId_ `string`: 

<a name="insertBeforeBlock" href="#insertBeforeBlock">#</a> **insertBeforeBlock**

Generator used to insert an empty block after a given block.

_Parameters_

-   _clientId_ `string`: 

<a name="insertBlock" href="#insertBlock">#</a> **insertBlock**

Returns an action object used in signalling that a single block should be
inserted, optionally at a specific index respective a root block list.

_Parameters_

-   _block_ `Object`: Block object to insert.
-   _index_ `?number`: Index at which block should be inserted.
-   _rootClientId_ `?string`: Optional root client ID of block list on which to insert.
-   _updateSelection_ `?boolean`: If true block selection will be updated. If false, block selection will not change. Defaults to true.

_Returns_

-   `Object`: Action object.

<a name="insertBlocks" href="#insertBlocks">#</a> **insertBlocks**

Returns an action object used in signalling that an array of blocks should
be inserted, optionally at a specific index respective a root block list.

_Parameters_

-   _blocks_ `Array<Object>`: Block objects to insert.
-   _index_ `?number`: Index at which block should be inserted.
-   _rootClientId_ `?string`: Optional root client ID of block list on which to insert.
-   _updateSelection_ `?boolean`: If true block selection will be updated.  If false, block selection will not change. Defaults to true.

_Returns_

-   `Object`: Action object.

<a name="insertDefaultBlock" href="#insertDefaultBlock">#</a> **insertDefaultBlock**

Returns an action object used in signalling that a new block of the default
type should be added to the block list.

_Parameters_

-   _attributes_ `?Object`: Optional attributes of the block to assign.
-   _rootClientId_ `?string`: Optional root client ID of block list on which to append.
-   _index_ `?number`: Optional index where to insert the default block

_Returns_

-   `Object`: Action object

<a name="mergeBlocks" href="#mergeBlocks">#</a> **mergeBlocks**

Returns an action object used in signalling that two blocks should be merged

_Parameters_

-   _firstBlockClientId_ `string`: Client ID of the first block to merge.
-   _secondBlockClientId_ `string`: Client ID of the second block to merge.

_Returns_

-   `Object`: Action object.

<a name="moveBlocksDown" href="#moveBlocksDown">#</a> **moveBlocksDown**

Undocumented declaration.

<a name="moveBlocksUp" href="#moveBlocksUp">#</a> **moveBlocksUp**

Undocumented declaration.

<a name="moveBlockToPosition" href="#moveBlockToPosition">#</a> **moveBlockToPosition**

Returns an action object signalling that an indexed block should be moved
to a new index.

_Parameters_

-   _clientId_ `?string`: The client ID of the block.
-   _fromRootClientId_ `?string`: Root client ID source.
-   _toRootClientId_ `?string`: Root client ID destination.
-   _index_ `number`: The index to move the block into.

<a name="multiSelect" href="#multiSelect">#</a> **multiSelect**

Returns an action object used in signalling that block multi-selection changed.

_Parameters_

-   _start_ `string`: First block of the multi selection.
-   _end_ `string`: Last block of the multiselection.

_Returns_

-   `Object`: Action object.

<a name="receiveBlocks" href="#receiveBlocks">#</a> **receiveBlocks**

Returns an action object used in signalling that blocks have been received.
Unlike resetBlocks, these should be appended to the existing known set, not
replacing.

_Parameters_

-   _blocks_ `Array<Object>`: Array of block objects.

_Returns_

-   `Object`: Action object.

<a name="removeBlock" href="#removeBlock">#</a> **removeBlock**

Returns an action object used in signalling that the block with the
specified client ID is to be removed.

_Parameters_

-   _clientId_ `string`: Client ID of block to remove.
-   _selectPrevious_ `boolean`: True if the previous block should be selected when a block is removed.

_Returns_

-   `Object`: Action object.

<a name="removeBlocks" href="#removeBlocks">#</a> **removeBlocks**

Yields action objects used in signalling that the blocks corresponding to
the set of specified client IDs are to be removed.

_Parameters_

-   _clientIds_ `(string|Array<string>)`: Client IDs of blocks to remove.
-   _selectPrevious_ `boolean`: True if the previous block should be selected when a block is removed.

<a name="replaceBlock" href="#replaceBlock">#</a> **replaceBlock**

Returns an action object signalling that a single block should be replaced
with one or more replacement blocks.

_Parameters_

-   _clientId_ `(string|Array<string>)`: Block client ID to replace.
-   _block_ `(Object|Array<Object>)`: Replacement block(s).

_Returns_

-   `Object`: Action object.

<a name="replaceBlocks" href="#replaceBlocks">#</a> **replaceBlocks**

Returns an action object signalling that a blocks should be replaced with
one or more replacement blocks.

_Parameters_

-   _clientIds_ `(string|Array<string>)`: Block client ID(s) to replace.
-   _blocks_ `(Object|Array<Object>)`: Replacement block(s).
-   _indexToSelect_ `number`: Index of replacement block to select.
-   _initialPosition_ `number`: Index of caret after in the selected block after the operation.

<a name="replaceInnerBlocks" href="#replaceInnerBlocks">#</a> **replaceInnerBlocks**

Returns an action object used in signalling that the inner blocks with the
specified client ID should be replaced.

_Parameters_

-   _rootClientId_ `string`: Client ID of the block whose InnerBlocks will re replaced.
-   _blocks_ `Array<Object>`: Block objects to insert as new InnerBlocks
-   _updateSelection_ `?boolean`: If true block selection will be updated. If false, block selection will not change. Defaults to true.

_Returns_

-   `Object`: Action object.

<a name="resetBlocks" href="#resetBlocks">#</a> **resetBlocks**

Returns an action object used in signalling that blocks state should be
reset to the specified array of blocks, taking precedence over any other
content reflected as an edit in state.

_Parameters_

-   _blocks_ `Array`: Array of blocks.

_Returns_

-   `Object`: Action object.

<a name="resetSelection" href="#resetSelection">#</a> **resetSelection**

Returns an action object used in signalling that selection state should be
reset to the specified selection.

_Parameters_

-   _selectionStart_ `WPBlockSelection`: The selection start.
-   _selectionEnd_ `WPBlockSelection`: The selection end.

_Returns_

-   `Object`: Action object.

<a name="selectBlock" href="#selectBlock">#</a> **selectBlock**

Returns an action object used in signalling that the block with the
specified client ID has been selected, optionally accepting a position
value reflecting its selection directionality. An initialPosition of -1
reflects a reverse selection.

_Parameters_

-   _clientId_ `string`: Block client ID.
-   _initialPosition_ `?number`: Optional initial position. Pass as -1 to reflect reverse selection.

_Returns_

-   `Object`: Action object.

<a name="selectionChange" href="#selectionChange">#</a> **selectionChange**

Returns an action object used in signalling that the user caret has changed
position.

_Parameters_

-   _clientId_ `string`: The selected block client ID.
-   _attributeKey_ `string`: The selected block attribute key.
-   _startOffset_ `number`: The start offset.
-   _endOffset_ `number`: The end offset.

_Returns_

-   `Object`: Action object.

<a name="selectNextBlock" href="#selectNextBlock">#</a> **selectNextBlock**

Yields action objects used in signalling that the block following the given
clientId should be selected.

_Parameters_

-   _clientId_ `string`: Block client ID.

<a name="selectPreviousBlock" href="#selectPreviousBlock">#</a> **selectPreviousBlock**

Yields action objects used in signalling that the block preceding the given
clientId should be selected.

_Parameters_

-   _clientId_ `string`: Block client ID.

<a name="setHasControlledInnerBlocks" href="#setHasControlledInnerBlocks">#</a> **setHasControlledInnerBlocks**

Returns an action object that sets whether the block has controlled innerblocks.

_Parameters_

-   _clientId_ `string`: The block's clientId.
-   _hasControlledInnerBlocks_ `boolean`: True if the block's inner blocks are controlled.

<a name="setNavigationMode" href="#setNavigationMode">#</a> **setNavigationMode**

Generators that triggers an action used to enable or disable the navigation mode.

_Parameters_

-   _isNavigationMode_ `string`: Enable/Disable navigation mode.

<a name="setTemplateValidity" href="#setTemplateValidity">#</a> **setTemplateValidity**

Returns an action object resetting the template validity.

_Parameters_

-   _isValid_ `boolean`: template validity flag.

_Returns_

-   `Object`: Action object.

<a name="showInsertionPoint" href="#showInsertionPoint">#</a> **showInsertionPoint**

Returns an action object used in signalling that the insertion point should
be shown.

_Parameters_

-   _rootClientId_ `?string`: Optional root client ID of block list on which to insert.
-   _index_ `?number`: Index at which block should be inserted.

_Returns_

-   `Object`: Action object.

<a name="startDraggingBlocks" href="#startDraggingBlocks">#</a> **startDraggingBlocks**

Returns an action object used in signalling that the user has begun to drag blocks.

_Returns_

-   `Object`: Action object.

<a name="startMultiSelect" href="#startMultiSelect">#</a> **startMultiSelect**

Returns an action object used in signalling that a block multi-selection has started.

_Returns_

-   `Object`: Action object.

<a name="startTyping" href="#startTyping">#</a> **startTyping**

Returns an action object used in signalling that the user has begun to type.

_Returns_

-   `Object`: Action object.

<a name="stopDraggingBlocks" href="#stopDraggingBlocks">#</a> **stopDraggingBlocks**

Returns an action object used in signalling that the user has stopped dragging blocks.

_Returns_

-   `Object`: Action object.

<a name="stopMultiSelect" href="#stopMultiSelect">#</a> **stopMultiSelect**

Returns an action object used in signalling that block multi-selection stopped.

_Returns_

-   `Object`: Action object.

<a name="stopTyping" href="#stopTyping">#</a> **stopTyping**

Returns an action object used in signalling that the user has stopped typing.

_Returns_

-   `Object`: Action object.

<a name="synchronizeTemplate" href="#synchronizeTemplate">#</a> **synchronizeTemplate**

Returns an action object synchronize the template with the list of blocks

_Returns_

-   `Object`: Action object.

<a name="toggleBlockHighlight" href="#toggleBlockHighlight">#</a> **toggleBlockHighlight**

Returns an action object that toggles the highlighted block state.

_Parameters_

-   _clientId_ `string`: The block's clientId.
-   _isHighlighted_ `boolean`: The highlight state.

<a name="toggleBlockMode" href="#toggleBlockMode">#</a> **toggleBlockMode**

Returns an action object used to toggle the block editing mode between
visual and HTML modes.

_Parameters_

-   _clientId_ `string`: Block client ID.

_Returns_

-   `Object`: Action object.

<a name="toggleSelection" href="#toggleSelection">#</a> **toggleSelection**

Returns an action object that enables or disables block selection.

_Parameters_

-   _isSelectionEnabled_ `[boolean]`: Whether block selection should be enabled.

_Returns_

-   `Object`: Action object.

<a name="updateBlock" href="#updateBlock">#</a> **updateBlock**

Returns an action object used in signalling that the block with the
specified client ID has been updated.

_Parameters_

-   _clientId_ `string`: Block client ID.
-   _updates_ `Object`: Block attributes to be merged.

_Returns_

-   `Object`: Action object.

<a name="updateBlockAttributes" href="#updateBlockAttributes">#</a> **updateBlockAttributes**

Returns an action object used in signalling that the block attributes with
the specified client ID has been updated.

_Parameters_

-   _clientId_ `string`: Block client ID.
-   _attributes_ `Object`: Block attributes to be merged.

_Returns_

-   `Object`: Action object.

<a name="updateBlockListSettings" href="#updateBlockListSettings">#</a> **updateBlockListSettings**

Returns an action object that changes the nested settings of a given block.

_Parameters_

-   _clientId_ `string`: Client ID of the block whose nested setting are being received.
-   _settings_ `Object`: Object with the new settings for the nested block.

_Returns_

-   `Object`: Action object

<a name="updateSettings" href="#updateSettings">#</a> **updateSettings**

Returns an action object used in signalling that the block editor settings have been updated.

_Parameters_

-   _settings_ `Object`: Updated settings

_Returns_

-   `Object`: Action object


<!-- END TOKEN(Autogenerated actions|../../../../packages/block-editor/src/store/actions.js) -->
