# Shortcode

Shortcode module for WordPress.

## Installation

Install the module

```bash
npm install @wordpress/shortcode --save
```

_This package assumes that your code will run in an **ES2015+** environment. If you're using an environment that has limited or no support for ES2015+ such as lower versions of IE then using [core-js](https://github.com/zloirock/core-js) or [@babel/polyfill](https://babeljs.io/docs/en/next/babel-polyfill) will add support for these methods. Learn more about it in [Babel docs](https://babeljs.io/docs/en/next/caveats)._

## API

<!-- START TOKEN(Autogenerated API docs) -->

<a name="attrs" href="#attrs">#</a> **attrs**

Parse shortcode attributes.

Shortcodes accept many types of attributes. These can chiefly be divided into
named and numeric attributes:

Named attributes are assigned on a key/value basis, while numeric attributes
are treated as an array.

Named attributes can be formatted as either `name="value"`, `name='value'`,
or `name=value`. Numeric attributes can be formatted as `"value"` or just
`value`.

_Parameters_

-   _text_ `string`: Serialised shortcode attributes.

_Returns_

-   `WPShortcodeAttrs`: Parsed shortcode attributes.

<a name="default" href="#default">#</a> **default**

Creates a shortcode instance.

To access a raw representation of a shortcode, pass an `options` object,
containing a `tag` string, a string or object of `attrs`, a string indicating
the `type` of the shortcode ('single', 'self-closing', or 'closed'), and a
`content` string.

_Parameters_

-   _options_ `Object`: Options as described.

_Returns_

-   `WPShortcode`: Shortcode instance.

<a name="fromMatch" href="#fromMatch">#</a> **fromMatch**

Generate a Shortcode Object from a RegExp match.

Accepts a `match` object from calling `regexp.exec()` on a `RegExp` generated
by `regexp()`. `match` can also be set to the `arguments` from a callback
passed to `regexp.replace()`.

_Parameters_

-   _match_ `Array`: Match array.

_Returns_

-   `WPShortcode`: Shortcode instance.

<a name="next" href="#next">#</a> **next**

Find the next matching shortcode.

_Parameters_

-   _tag_ `string`: Shortcode tag.
-   _text_ `string`: Text to search.
-   _index_ `number`: Index to start search from.

_Returns_

-   `?WPShortcodeMatch`: Matched information.

<a name="regexp" href="#regexp">#</a> **regexp**

Generate a RegExp to identify a shortcode.

The base regex is functionally equivalent to the one found in
`get_shortcode_regex()` in `wp-includes/shortcodes.php`.

Capture groups:

1.  An extra `[` to allow for escaping shortcodes with double `[[]]`
2.  The shortcode name
3.  The shortcode argument list
4.  The self closing `/`
5.  The content of a shortcode when it wraps some content.
6.  The closing tag.
7.  An extra `]` to allow for escaping shortcodes with double `[[]]`

_Parameters_

-   _tag_ `string`: Shortcode tag.

_Returns_

-   `RegExp`: Shortcode RegExp.

<a name="replace" href="#replace">#</a> **replace**

Replace matching shortcodes in a block of text.

_Parameters_

-   _tag_ `string`: Shortcode tag.
-   _text_ `string`: Text to search.
-   _callback_ `Function`: Function to process the match and return replacement string.

_Returns_

-   `string`: Text with shortcodes replaced.

<a name="string" href="#string">#</a> **string**

Generate a string from shortcode parameters.

Creates a shortcode instance and returns a string.

Accepts the same `options` as the `shortcode()` constructor, containing a
`tag` string, a string or object of `attrs`, a boolean indicating whether to
format the shortcode using a `single` tag, and a `content` string.

_Parameters_

-   _options_ `Object`: 

_Returns_

-   `string`: String representation of the shortcode.


<!-- END TOKEN(Autogenerated API docs) -->

<br/><br/><p align="center"><img src="https://s.w.org/style/images/codeispoetry.png?1" alt="Code is Poetry." /></p>
